ContainmentMode class abstract

Values representing polyfill containment modes, to be used in the flags bit field for polygonToCellsExperimental.

Constructors

ContainmentMode()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CONTAINMENT_CENTER → const int
< Cell center is contained in the shape
CONTAINMENT_FULL → const int
< Cell is fully contained in the shape
CONTAINMENT_INVALID → const int
< This mode is invalid and should not be used
CONTAINMENT_OVERLAPPING → const int
< Cell overlaps the shape at any point
CONTAINMENT_OVERLAPPING_BBOX → const int
< Cell bounding box overlaps shape