GeoPolygon class

@struct GeoPolygon @brief Simplified core of GeoJSON Polygon coordinates definition

Inheritance
Implemented types
Available extensions

Constructors

GeoPolygon()

Properties

address → Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
geoloop ↔ GeoLoop
< exterior boundary of the polygon
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
holes ↔ Pointer<GeoLoop>
< interior boundaries (holes) in the polygon
getter/setter pair
numHoles ↔ int
< number of elements in the array pointed to by holes
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited